@@ -8,7 +8,7 @@ test_data <- january2018
 # test inputs ------------------------------------------------
 
 test_that("misspecified functions return errors", {
-  expect_error(cs_replace0(var = XCoord),
+  expect_error(cs_replace0(var = x_coord),
                "An existing data frame with data to be edited must be specified for '.data'.")
   expect_error(cs_replace0(test_data),
                "The column containing coordinate data must be specified for 'var'.")
@@ -17,16 +17,16 @@ test_that("misspecified functions return errors", {
 # test function ------------------------------------------------
 
 test_that("correctly specified functions execute without error", {
-  expect_error(cs_replace0(test_data, var = XCoord), NA)
-  expect_error(cs_replace0(test_data, var = "YCoord"), NA)
+  expect_error(cs_replace0(test_data, var = x_coord), NA)
+  expect_error(cs_replace0(test_data, var = "y_coord"), NA)
 })
 
 # test results ------------------------------------------------
 
-results <- cs_replace0(test_data, var = XCoord)
-results <- cs_replace0(results, var = YCoord)
+results <- cs_replace0(test_data, var = x_coord)
+results <- cs_replace0(results, var = y_coord)
 
 test_that("correct output is returned on sample data", {
-  expect_equal(sum(is.na(results$XCoord)), 98)
-  expect_equal(sum(is.na(results$YCoord)), 98)
+  expect_equal(sum(is.na(results$x_coord)), 98)
+  expect_equal(sum(is.na(results$y_coord)), 98)
 })
